SubmoduleEntry

Struct SubmoduleEntry 

pub struct SubmoduleEntry {
    pub state: SubmoduleState,
    pub sha: String,
    pub path: String,
    pub describe: String,
}
One configured submodule.

Fields

state: SubmoduleStatesha: String

The commit the submodule is at (full SHA, as git prints it).

path: String

Path relative to the superproject’s working tree.

describe: String

The git describe output git appends in parentheses, when there is one. Empty for an uninitialised submodule, which has no checkout to describe.