WorkingTree

Struct WorkingTree 

pub struct WorkingTree;
Working tree and index status operations.

Uses git status --porcelain=v1 for status classification.

Implementations

Source

impl WorkingTree

pub fn path_status( repo: &Repository, path: impl AsRef<Path>, ) -> Result<PathChange>

Return the status of a single path in the repository.

Uses git status --porcelain=v1 -- <path>.

pub fn statuses(repo: &Repository) -> Result<Vec<(PathBuf, PathChange)>>

Return the status of every file in the working tree that has changed relative to the index or HEAD.

Includes untracked files. Uses git status --porcelain=v1.